Supported Devices
=================

The following is an (incomplete) list of the supported devices, mostly taken from `Home Assistant`_.

Other devices may work, but were not reported by any user.

If you find wrong or missing information don't hesitate to file an issue_ or submit a merge request!

.. _issue: https://gitlab.com/stavros/python-yeelight/-/issues/new
.. _Home Assistant: https://www.home-assistant.io/integrations/yeelight/

.. list-table:: Supported Devices
   :widths: 15 15 70
   :header-rows: 1

   * - Model ID
     - Model number
     - Product name
   * - `mono`
     - YLTD03YL
     - Yeelight Serene Eye-Friendly Desk Lamp
   * - `mono1`
     - YLDP01YL
     - LED Bulb (White)
   * - `mono5`
     - -
     - Yeelight Filament Bulb (White)
   * - `monob`
     - -
     - -
   * - -
     - YLDP05YL
     - Smaert LED Bulb (Tunable White) - 2nd generation
   * - `color`
     - -
     - -
   * - `color1`
     - YLDP02YL
     - LED Bulb (Color)
   * - `color1`
     - YLDP03YL
     - LED Bulb (Color) - E26 socket
   * - `color2`
     - YLDP06YL
     - LED Bulb (Color) - 2nd generation
   * - `color4`
     - YLDP13YL
     - LED Bulb 1S (Color)
   * - `color4`
     - YLDP04YL
     - LED Bulb 1S (Color)
   * - `color5`
     - MJDPL04YL
     - Xiaomi Mi Smart LED Bulb Essential (White and Color) - EU
   * - `colorc`
     - YLDP004-A
     - GU10 W1 (Color)
   * - `strip1`
     - YLDD01YL
     - Lightstrip (Color)
   * - `strip1`
     - YLDD02YL
     - Lightstrip (Color)
   * - `strip2`
     - -
     - -
   * - `strip4`
     - YLDD03YL
     - Lightstrip (Color)
   * - -
     - YLDD04YL
     - Lightstrip (Color)
   * - `strip6`
     - YLDD05YL
     - Lightstrip (Color)
   * - `RGBW`
     - MJDP02YL
     - Mi LED smart Lamp - white and color Wi-Fi Version|
   * - `lamp1`
     - MJTD01YL
     - Xiaomi Mijia Smart LED Desk Lamp (autodiscovery isn't possible because the device doesn't support mDNS due to the small amount of RAM)
   * - `lamp3`
     - YLTD03YL
     - Yeelight Serene Eye-Friendly Desk Lamp (White)
   * - `lamp4`
     - -
     - -
   * - `lamp15`
     - YLTD003
     - Yeelight LED Screen Light Bar Pro
   * - `bslamp1`
     - MJCTD01YL
     - Xiaomi Mijia Bedside Lamp - Wi-Fi Version!
   * - `bslamp1`
     - MJCTD02YL
     - Xiaomi Mijia Bedside Lamp II
   * - `bslamp2`
     - -
     - -
   * - `bslamp3`
     - -
     - -
   * - `ceiling1`
     - YLXD01YL
     - Yeelight Ceiling Light
   * - `ceiling2`
     - YLXD03YL
     - Yeelight Ceiling Light - Youth Version
   * - -, may be `ceiling3`
     - YLXD04YL
     - Yeelight Ceiling Light (Jiaoyue 450)
   * - `ceiling3`
     - YLXD05YL
     - Yeelight Ceiling Light (Jiaoyue 480)
   * - `ceiling4`
     - YLXD02YL
     - Yeelight Ceiling Light (Jiaoyue 650)
   * - `ceiling5`
     - -
     - -
   * - `ceiling6`
     - YLXD08YL
     - Yeelight Ceiling Light
   * - `ceiling10`
     - YLDL01YL
     - Yeelight Meteorite Pendant Light
   * - `ceiling13`
     - YLXD01YL
     - Yeelight LED Ceiling Light
   * - `ceiling15`
     - YLXD42YL
     - Yeelight LED Ceiling Light
   * - `ceiling18`
     - -
     - -
   * - `ceiling19`
     - YLXD49YL
     - Yeelight LED Ceiling Light
   * - `ceiling20`
     - -
     - -
   * - `ceiling24`
     - -
     - -
   * - `ceil26`
     - -
     - -
   * - `ceila`
     - YLXD76YL
     - Yeelight Ceiling Light - Updated HomeKit 23w
   * - `ceilc`
     - -
     - -
   * - `ct_bulb`
     - -
     - -
   * - `ct2`
     - -
     - -

..
   * - `color6`
     - YLDP13AYL
     - LED Bulb 1S (Color)
   * - `colorb`
     - YLDP005
     - LED Bulb (Color)
   * - `lamp`
     - MJTD02YL
     - Xiaomi Mijia Desk Lamp Pro
   * - `lamp9`
     - YLCT03YL
     - Yeelight Staria Bedside Lamp Pro
   * - -
     - YLXD62YI
     - Yeelight Ceiling Light (Jiaoyue 260)
   * - -, may be `ceilb`
     - YLXD013-B
     - Yeelight Arwen Ceiling Light 450C
   * - -, may be `ceilb`
     - YLXD013-C
     - Yeelight Arwen Ceiling Light 550C
   * - `ceilb`
     - YLXD013
     - Yeelight Arwen Ceiling Light 450S
